@@ -397,7 +397,8 @@ _mzml_schema_defaults = {'ints': {
      ('softwareList', 'count'),
      ('binaryDataArrayList', 'count'),
      ('spectrumList', 'count'),
-     ('chromatogramList', 'count')},
+     ('chromatogramList', 'count'),
+     ('selectedIon', 'charge state')},
         'floats': {},
         'bools': {},
         'lists': {'scan', 'spectrum', 'sample', 'cv', 'dataProcessing',
