@@ -9,6 +9,7 @@ import multiprocessing as mp
 import threading
 import warnings
 import os
+from abc import ABCMeta
 
 try:
     basestring
@@ -47,7 +48,8 @@ try:
 except ImportError:
     from collections import Sequence
 
-from . import PyteomicsError
+from .structures import PyteomicsError
+from .utils import add_metaclass
 
 
 def _keepstate(func):
@@ -181,6 +183,7 @@ class IteratorContextManager(NoOpBaseReader):
     next = __next__
 
 
+@add_metaclass(ABCMeta)
 class FileReader(IteratorContextManager):
     """Abstract class implementing context manager protocol
     for file readers.
@@ -573,14 +576,32 @@ def _file_writer(_mode='a'):
         """
         @wraps(_func)
         def helper(*args, **kwargs):
-            m = kwargs.pop('file_mode', _mode)
+            if 'file_mode' in kwargs:
+                m = kwargs.pop('file_mode')
+                warn = False
+            else:
+                m = _mode
+                warn = True
             enc = kwargs.pop('encoding', None)
             if len(args) > 1:
-                with _file_obj(args[1], m, encoding=enc) as out:
-                    return _func(args[0], out, *args[2:], **kwargs)
+                out_arg = args[1]
             else:
-                with _file_obj(kwargs.pop('output', None), m, encoding=enc) as out:
-                    return _func(*args, output=out, **kwargs)
+                out_arg = kwargs.pop('output', None)
+
+            # warn about the change in default mode if an existing file name is given
+            if isinstance(out_arg, basestring) and warn and os.path.exists(out_arg):
+                warnings.warn("Opening an existing file in append mode. "
+                    "The default mode will change from 'a' to 'w' in a future version. "
+                    "Pass `file_mode='a'` to keep old behavior and suppress this warning.", FutureWarning)
+
+            with _file_obj(out_arg, m, encoding=enc) as out:
+                if len(args) > 1:
+                    call_args = (args[0], out) + args[2:]
+                    call_kwargs = kwargs
+                else:
+                    call_args = args
+                    call_kwargs = dict(output=out, **kwargs)
+                return _func(*call_args, **call_kwargs)
         return helper
     return decorator
 
@@ -912,7 +933,7 @@ def _check_use_index(source, use_index, default):
                 warnings.warn('use_index is {}, but the file mode is {}. '
                     'Setting `use_index` to {}'.format(use_index, source.mode, binary))
             use_index = binary
-        else:
+        elif use_index is None:
             warnings.warn('Could not check mode on {}. Specify `use_index` explicitly to avoid errors.'.format(source))
 
         if use_index is not None:
@@ -923,10 +944,11 @@ def _check_use_index(source, use_index, default):
     except PyteomicsError:
         raise
     except Exception as e:
-        warnings.warn('Could not check mode on {}. Reason: {!r}. Specify `use_index` explicitly to avoid errors.'.format(source, e))
-        if use_index is not None:
-            return use_index
-        return default
+        if use_index is None:
+            warnings.warn('Could not check mode on {}. Reason: {!r}. '
+                'Specify `use_index` explicitly to avoid errors.'.format(source, e))
+            return default
+        return use_index
 
 
 class FileReadingProcess(mp.Process):
