@@ -394,6 +394,7 @@ std_aa_comp.update({
     'G':   Composition({'H': 3, 'C': 2, 'O': 1, 'N': 1}),
     'H':   Composition({'H': 7, 'C': 6, 'N': 3, 'O': 1}),
     'I':   Composition({'H': 11, 'C': 6, 'O': 1, 'N': 1}),
+    'J':   Composition({'H': 11, 'C': 6, 'O': 1, 'N': 1}),
     'K':   Composition({'H': 12, 'C': 6, 'N': 2, 'O': 1}),
     'L':   Composition({'H': 11, 'C': 6, 'O': 1, 'N': 1}),
     'M':   Composition({'H': 9, 'C': 5, 'S': 1, 'O': 1, 'N': 1}),
@@ -726,6 +727,7 @@ std_aa_mass = {
     'C': 103.00919,
     'L': 113.08406,
     'I': 113.08406,
+    'J': 113.08406,
     'N': 114.04293,
     'D': 115.02694,
     'Q': 128.05858,
