@@ -97,6 +97,7 @@ This module requires :py:mod:`lxml`.
 from lxml import etree
 from . import xml, auxiliary as aux, _schema_defaults
 
+
 class PepXML(xml.MultiProcessingXML, xml.IndexSavingXML):
     """Parser class for pepXML files."""
     file_format = 'pepXML'
@@ -109,7 +110,7 @@ class PepXML(xml.MultiProcessingXML, xml.IndexSavingXML):
     _default_id_attr = 'spectrum'
     _structures_to_flatten = {'search_score_summary', 'modification_info'}
     # attributes which contain unconverted values
-    _convert_items = {'float':  {'calc_neutral_pep_mass', 'massdiff',
+    _convert_items = {'float': {'calc_neutral_pep_mass', 'massdiff',
             'probability', 'variable', 'static'},
         'int': {'start_scan', 'end_scan', 'index', 'num_matched_peptides'},
         'bool': {'is_rejected'},
@@ -123,13 +124,9 @@ class PepXML(xml.MultiProcessingXML, xml.IndexSavingXML):
             name = xml._local_name(element)
         rec = kwargs.pop('recursive', None)
         if name == self._root_element:
-            info = self._get_info(element, ename=name,
-                    recursive=(rec if rec is not None else False),
-                    **kwargs)
+            info = self._get_info(element, ename=name, recursive=(rec if rec is not None else False), **kwargs)
         else:
-            info = self._get_info(element, ename=name,
-                    recursive=(rec if rec is not None else True),
-                    **kwargs)
+            info = self._get_info(element, ename=name, recursive=(rec if rec is not None else True), **kwargs)
 
         def safe_float(s):
             try:
@@ -137,7 +134,7 @@ class PepXML(xml.MultiProcessingXML, xml.IndexSavingXML):
             except ValueError:
                 if s.startswith('+-0'):
                     return 0
-                return None
+                return s
 
         converters = {'float': safe_float, 'int': int,
                 'bool': lambda x: x.lower() in {'1', 'true'},
@@ -310,6 +307,7 @@ def roc_curve(source):
 
     return roc_curve
 
+
 # chain = aux._make_chain(read, 'read')
 chain = aux.ChainBase._make_chain(read)
 
@@ -334,15 +332,15 @@ def _is_decoy_prefix(psm, prefix='DECOY_'):
     return all(protein['protein'].startswith(prefix)
             for protein in psm['search_hit'][0]['proteins'])
 
+
 def _is_decoy_suffix(psm, suffix='_DECOY'):
     return all(protein['protein'].endswith(suffix)
             for protein in psm['search_hit'][0]['proteins'])
 
-is_decoy = _is_decoy_prefix
 
+is_decoy = _is_decoy_prefix
 fdr = aux._make_fdr(_is_decoy_prefix, _is_decoy_suffix)
-_key = lambda x: min(
-    sh['search_score']['expect'] for sh in x['search_hit'])
+_key = lambda x: min(sh['search_score']['expect'] for sh in x['search_hit'])
 qvalues = aux._make_qvalues(chain, _is_decoy_prefix, _is_decoy_suffix, _key)
 filter = aux._make_filter(chain, _is_decoy_prefix, _is_decoy_suffix, _key, qvalues)
 filter.chain = aux._make_chain(filter, 'filter', True)
