@@ -13,6 +13,13 @@ One use-case for USI is to request spectrum information from a `PROXI <http://ww
 service host. PROXI services are available from several of the major national proteomics data hosts,
 including MassIVE, PeptideAtlas, PRIDE, and jPOST.
 
+.. seealso::
+   LeDuc, Richard D., Eric W. Deutsch, Pierre-Alain Binz, Ryan T. Fellers, Anthony J. Cesnik,
+   Joshua A. Klein, Tim Van Den Bossche, et al.
+   "Proteomics Standards Initiative's ProForma 2.0: Unifying the Encoding of Proteoforms and Peptidoforms."
+   ArXiv:2109.11352 [q-Bio], September 23, 2021. http://arxiv.org/abs/2109.11352.
+
+
 
 Data access
 -----------
